@@ -37,6 +37,7 @@ __all__ = (
     "DistributionConfigurationTypeDef",
     "DistributionTypeDef",
     "EbsInstanceBlockDeviceSpecificationTypeDef",
+    "ImagePackageTypeDef",
     "ImagePipelineTypeDef",
     "ImageRecipeSummaryTypeDef",
     "ImageRecipeTypeDef",
@@ -87,6 +88,7 @@ __all__ = (
     "ListContainerRecipesResponseTypeDef",
     "ListDistributionConfigurationsResponseTypeDef",
     "ListImageBuildVersionsResponseTypeDef",
+    "ListImagePackagesResponseTypeDef",
     "ListImagePipelineImagesResponseTypeDef",
     "ListImagePipelinesResponseTypeDef",
     "ListImageRecipesResponseTypeDef",
@@ -309,11 +311,15 @@ EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
         "kmsKeyId": str,
         "snapshotId": str,
         "volumeSize": int,
-        "volumeType": Literal["standard", "io1", "io2", "gp2", "sc1", "st1"],
+        "volumeType": Literal["standard", "io1", "io2", "gp2", "gp3", "sc1", "st1"],
     },
     total=False,
 )
 
+ImagePackageTypeDef = TypedDict(
+    "ImagePackageTypeDef", {"packageName": str, "packageVersion": str}, total=False
+)
+
 ImagePipelineTypeDef = TypedDict(
     "ImagePipelineTypeDef",
     {
@@ -467,6 +473,8 @@ InfrastructureConfigurationSummaryTypeDef = TypedDict(
         "dateUpdated": str,
         "resourceTags": Dict[str, str],
         "tags": Dict[str, str],
+        "instanceTypes": List[str],
+        "instanceProfileName": str,
     },
     total=False,
 )
@@ -524,6 +532,7 @@ ScheduleTypeDef = TypedDict(
     "ScheduleTypeDef",
     {
         "scheduleExpression": str,
+        "timezone": str,
         "pipelineExecutionStartCondition": Literal[
             "EXPRESSION_MATCH_ONLY", "EXPRESSION_MATCH_AND_DEPENDENCY_UPDATES_AVAILABLE"
         ],
@@ -719,6 +728,12 @@ ListImageBuildVersionsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListImagePackagesResponseTypeDef = TypedDict(
+    "ListImagePackagesResponseTypeDef",
+    {"requestId": str, "imagePackageList": List["ImagePackageTypeDef"], "nextToken": str},
+    total=False,
+)
+
 ListImagePipelineImagesResponseTypeDef = TypedDict(
     "ListImagePipelineImagesResponseTypeDef",
     {"requestId": str, "imageSummaryList": List["ImageSummaryTypeDef"], "nextToken": str},
